==> iotpaycreditcard-0.0.1.tar.gz: lib/iotpaycreditcard.dart <==
library iotpaycreditcard;

import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

import 'config/MyConfig.dart';
import 'providers/dataProvider.dart';
import 'widgets/textfieldWidget.dart';

class CardWidget extends StatelessWidget {
  const CardWidget({
    Key key,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    double _thisTop = 18.0;

    /*List<FocusNode> nodeList = [
      FocusNode(),
      FocusNode(),
      FocusNode(),
      FocusNode()
    ];*/

    return Consumer<DataProvider>(builder: (context, dataProvider, child) {
      List<Map<String, Object>> items =
          dataProvider.formLists['credit']['items'];
      //print(items.toString());
      _onTab(String name, double screenWidth) {
        dataProvider.onTab(name, screenWidth);
      }

      _onChange(String name, String value) {
        dataProvider.onChange(name, value);
      }

      double getLeft(item, contextWidth) {
        double left = _thisTop;

        if (dataProvider.isTripleLine) {
          if (item['name'] == MyConfig.CVV.name) {
            left = item['inputLeft'].toDouble();
          }
        } else if (!dataProvider.isTripleLine) {
          left = item['inputLeft'].toDouble();
          if (item['name'] == MyConfig.EXPIRYDATE.name) {
            left = contextWidth - 138.0;
          }
          if (item['name'] == MyConfig.CVV.name) {
            left = contextWidth - 90.0;
          }
        }
        return left;
      }

      double getWidth(item, contextWidth) {
        double width = item['inputWidth'].toDouble();
        if (dataProvider.isTripleLine) {
          if (item['name'] == MyConfig.CARDNUMBER.name) {
            width = contextWidth - 80.0;
          } else if (item['name'] == MyConfig.HOLDER.name) {
            width = 190.0;
          }
        }
        return width;
      }

      List<Widget> _showItems() {
        List<Widget> result = [];
        double contextWidth = MediaQuery.of(context).size.width;
        result.add(Positioned(
          top: _thisTop,
          left: 0,
          child: dataProvider.isTripleLine && dataProvider.isBack
              ? Container(
                  width: contextWidth,
                  height: _thisTop + 23,
                  decoration: BoxDecoration(
                    gradient: LinearGradient(
                      begin: Alignment.topLeft,
                      end: Alignment.bottomRight,
                      colors: [Colors.black, Colors.black],
                    ),
                  ),
                )
              : Container(),
        ));
        result.add(Positioned(
          top: (contextWidth - 40) / 5 + 10,
          left: _thisTop - 5,
          child: dataProvider.isTripleLine && dataProvider.isBack
              ? Container(
                  width: 200,
                  height: _thisTop + 30,
                  decoration: BoxDecoration(
                    gradient: LinearGradient(
                      begin: Alignment.topLeft,
                      end: Alignment.bottomRight,
                      colors: [Colors.white, Colors.white],
                    ),
                  ),
                )
              : Container(),
        ));

        for (var i = 0; i < items.length; i++) {
          var item = items[i];

          result.add(Positioned(
            top: dataProvider.isTripleLine
                ? (contextWidth - 40) * item['inputRow'] / 5 + 10
                : _thisTop,
            left: getLeft(item, contextWidth),
            child: TextFieldWidget(
              width: getWidth(item, contextWidth),
              focused: true,
              hintTxt: dataProvider.isTripleLine
                  ? item['placeholder'].toString()
                  : item['placeholdershort'],
              keyboardtype: item['inputType'],
              suffixIcon: item['sufficIcon'],
              onTab: () => {_onTab(item['name'].toString(), contextWidth)},
              onChanged: (String value) =>
                  {_onChange(item['name'].toString(), value)},
              textFieldController: item['txtEditingController'],
              textFontColor: item['name'] == MyConfig.CARDNUMBER.name
                  ? Colors.white
                  : Colors.black,
              fontSize: item['fontSize'],
              fontStyle: item['fontStyle'],
              fontWeight: item['fontWeight'],
            ),
          ));
        }

        return result;
      }

      return Container(
        height: dataProvider.isTripleLine
            ? (MediaQuery.of(context).size.width - 40) * 5 / 8
            : 80,
        width: MediaQuery.of(context).size.width - 40,
        child: ConstrainedBox(
          constraints: BoxConstraints.expand(),
          child: Stack(
            alignment: Alignment
                .topLeft, //æŒ‡å®šæœªå®šä½æˆ–éƒ¨åˆ†å®šä½widgetçš„å¯¹é½æ–¹å¼
            children: _showItems(),
          ),
        ),
        decoration: BoxDecoration(
            boxShadow: dataProvider.isTripleLine && dataProvider.isBack
                ? []
                : [
                    BoxShadow(
                      color: Colors.black,
                      blurRadius: 0.0, // soften the shadow
                      spreadRadius: 0.0, //extend the shadow
                      offset: Offset(
                        2.0, // Move to right 10  horizontally
                        2.0, // Move to bottom 10 Vertically
                      ),
                    )
                  ],
            gradient: LinearGradient(
              begin: Alignment.topLeft,
              end: Alignment.bottomRight,
              colors: dataProvider.isTripleLine && dataProvider.isBack
                  ? [Color(0x77737373), Color(0x77737373)]
                  : [Color(0xf2f2f2f2), Color(0x77737373)],
            ),
            borderRadius: BorderRadius.all(Radius.circular(20)),
            color: Colors.blue),
      );
    });
  }
}

==> iotpaycreditcard-0.0.5.tar.gz: lib/iotpaycreditcard.dart <==
library iotpaycreditcard;

import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

import 'config/MyConfig.dart';
import 'providers/dataProvider.dart';
import 'widgets/textfieldWidget.dart';

class CardWidget extends StatelessWidget {
  const CardWidget({
    Key key,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    double _thisTop = 18.0;

    /*List<FocusNode> nodeList = [
      FocusNode(),
      FocusNode(),
      FocusNode(),
      FocusNode()
    ];*/

    return Consumer<DataProvider>(builder: (context, dataProvider, child) {
      List<Map<String, Object>> items =
          dataProvider.formLists['credit']['items'];
      //print(items.toString());

      double getLeft(item, contextWidth) {
        double left = _thisTop;

        if (dataProvider.isTripleLine) {
          if (item['name'] == MyConfig.CVV.name) {
            left = item['inputLeft'].toDouble();
          }
        } else if (!dataProvider.isTripleLine) {
          left = item['inputLeft'].toDouble();
          if (item['name'] == MyConfig.EXPIRYDATE.name) {
            left = contextWidth - 138.0;
          }
          if (item['name'] == MyConfig.CVV.name) {
            left = contextWidth - 90.0;
          }
        }
        return left;
      }

      /*double getWidth(item, contextWidth) {
        double width = item['inputWidth'].toDouble();
        if (dataProvider.isTripleLine) {
          if (item['name'] == MyConfig.CARDNUMBER.name) {
            width = contextWidth - 80.0;
          } else if (item['name'] == MyConfig.HOLDER.name) {
            width = 190.0;
          }
        }
        return width;
      }*/

      List<Widget> _showItems() {
        List<Widget> result = [];
        double contextWidth = MediaQuery.of(context).size.width;
        result.add(Positioned(
          top: _thisTop,
          left: 0,
          child: dataProvider.isTripleLine && dataProvider.isBack
              ? Container(
                  width: contextWidth,
                  height: _thisTop + 23,
                  decoration: BoxDecoration(
                    gradient: LinearGradient(
                      begin: Alignment.topLeft,
                      end: Alignment.bottomRight,
                      colors: [Colors.black, Colors.black],
                    ),
                  ),
                )
              : Container(),
        ));
        result.add(Positioned(
          top: (contextWidth - 40) / 5 + 10,
          left: _thisTop - 5,
          child: dataProvider.isTripleLine && dataProvider.isBack
              ? Container(
                  width: 200,
                  height: _thisTop + 30,
                  decoration: BoxDecoration(
                    gradient: LinearGradient(
                      begin: Alignment.topLeft,
                      end: Alignment.bottomRight,
                      colors: [Colors.white, Colors.white],
                    ),
                  ),
                )
              : Container(),
        ));

        for (var i = 0; i < items.length; i++) {
          var item = items[i];

          result.add(Positioned(
            top: dataProvider.isTripleLine
                ? (contextWidth - 40) * item['inputRow'] / 5 + 10
                : _thisTop,
            left: getLeft(item, contextWidth),
            child: TextFieldWidget(
              dataProvider: dataProvider,
              contextWidth: contextWidth,
              item: item,
            ),
          ));
        }

        return result;
      }

      return Container(
        height: dataProvider.isTripleLine
            ? (MediaQuery.of(context).size.width - 40) * 5 / 8
            : 80,
        width: MediaQuery.of(context).size.width - 40,
        child: ConstrainedBox(
          constraints: BoxConstraints.expand(),
          child: Stack(
            alignment: Alignment
                .topLeft, //æŒ‡å®šæœªå®šä½æˆ–éƒ¨åˆ†å®šä½widgetçš„å¯¹é½æ–¹å¼
            children: _showItems(),
          ),
        ),
        decoration: BoxDecoration(
            boxShadow: dataProvider.isTripleLine && dataProvider.isBack
                ? []
                : [
                    BoxShadow(
                      color: Colors.black,
                      blurRadius: 0.0, // soften the shadow
                      spreadRadius: 0.0, //extend the shadow
                      offset: Offset(
                        2.0, // Move to right 10  horizontally
                        2.0, // Move to bottom 10 Vertically
                      ),
                    )
                  ],
            gradient: LinearGradient(
              begin: Alignment.topLeft,
              end: Alignment.bottomRight,
              colors: dataProvider.isTripleLine && dataProvider.isBack
                  ? [Color(0x77737373), Color(0x77737373)]
                  : [Color(0xf2f2f2f2), Color(0x77737373)],
            ),
            borderRadius: BorderRadius.all(Radius.circular(20)),
            color: Colors.blue),
      );
    });
  }
}
